@@ -1,5 +1,6 @@
 from django.apps import AppConfig
 from django.conf import settings
+from django.db.models.signals import post_migrate
 
 from . import monkey_patch_group, monkey_patch_user
 
@@ -9,6 +10,9 @@ class GuardianConfig(AppConfig):
     default_auto_field = "django.db.models.AutoField"
 
     def ready(self):
+        from .shortcuts import clear_ct_cache
+
+        post_migrate.connect(clear_ct_cache)
         if settings.GUARDIAN_MONKEY_PATCH_GROUP:
             monkey_patch_group()
         if settings.GUARDIAN_MONKEY_PATCH_USER:
